<?php

namespace Ardent\Undercurrent\View;

use Ardent\Undercurrent\AppConfig;

class BaseView implements ViewInterface
{
    private ViewHelper $helper;

    public function __construct(
        private readonly string $path,
        private readonly array  $data = [],
        private ?string         $extends = null,
    )
    {
    }

    public function render(AppConfig $config, ViewHelper $helper): string
    {
        $this->helper = $helper;
        $path = $config->getTemplatePath() . $this->path;
        if (!str_ends_with($path, '.php')) {
            $path .= '.php';
        }

        if (!file_exists($path)) {
            throw new \RuntimeException(sprintf('View file %s does not exist', $path));
        }

        ob_start();
        include $path;
        $output = ob_get_clean();
        if ($this->extends) {
            return (new BaseView($this->extends, $this->data + ['slot' => $output]))->render(...func_get_args());
        }

        return $output;
    }

    public function getRoute(string $class, string $method, array $params = []): string
    {
        return $this->helper->getRouter()->toUri($class, $method, $params);
    }
}